const React = require('react');
const privateRoute = require('./components/privateRoute').default;
const LoginWrapper = require('./components/loginWrapper').default;
const {defaultAdminPath} = require('./utils/config');

// Taken from https://github.com/netlify/netlify-identity-widget
const routes = /(confirmation|invite|recovery|email_change)_token=([^&]+)/;
const errorRoute = /error=access_denied&error_description=403/;
const accessTokenRoute = /access_token=/;

export const onInitialClientRender = (_, pluginOptions) => {
    const { adminPath = defaultAdminPath } = pluginOptions;
    const enableIdentityWidget = true;

    const hash = (document.location.hash || ``).replace(/^#\/?/, ``);

    if (
        enableIdentityWidget &&
        (routes.test(hash) ||
            errorRoute.test(hash) ||
            accessTokenRoute.test(hash))
    ) {
        import(`netlify-identity-widget`).then(
            ({ default: netlifyIdentityWidget }) => {
                netlifyIdentityWidget.on(`init`, (user) => {
                    if (!user) {
                        netlifyIdentityWidget.on(`login`, () => {
                            document.location.href = `${__PATH_PREFIX__}/${adminPath}/`;
                        });
                    }
                });
                netlifyIdentityWidget.init();
            }
        );
    }
};

exports.wrapPageElement = ({ element, props }, pluginOptions) => {
    const { loginPath } = pluginOptions;
    const { netlifyAdminPlugin } = props.pageContext;
    if (netlifyAdminPlugin) {
        if (netlifyAdminPlugin.shouldExclude) {
            // return loginWrapper(element);
            return <LoginWrapper element={element} />
        }

        return privateRoute({
            component: <LoginWrapper element={element} />,
            path: props.uri,
            loginPath,
        });
    }
    return element;
};
